<?php
/**
 * VW Charity NGO Theme Customizer
 *
 * @package VW Charity NGO
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function vw_charity_ngo_customize_register( $wp_customize ) {

	//add home page setting pannel
	$wp_customize->add_panel( 'vw_charity_ngo_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'vw-charity-ngo' ),
	    'description' => __( 'Description of what this panel does.', 'vw-charity-ngo' ),
	) );

	$wp_customize->add_section( 'vw_charity_ngo_left_right', array(
    	'title'      => __( 'General Settings', 'vw-charity-ngo' ),
		'priority'   => 30,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	// Add Settings and Controls for Layout
	$wp_customize->add_setting('vw_charity_ngo_theme_options',array(
        'default' => __('Right Sidebar','vw-charity-ngo'),
        'sanitize_callback' => 'vw_charity_ngo_sanitize_choices'	        
	));
	$wp_customize->add_control('vw_charity_ngo_theme_options',array(
        'type' => 'radio',
        'label' => __('Do you want this section','vw-charity-ngo'),
        'section' => 'vw_charity_ngo_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','vw-charity-ngo'),
            'Right Sidebar' => __('Right Sidebar','vw-charity-ngo'),
            'One Column' => __('One Column','vw-charity-ngo'),
            'Three Columns' => __('Three Columns','vw-charity-ngo'),
            'Four Columns' => __('Four Columns','vw-charity-ngo'),
            'Grid Layout' => __('Grid Layout','vw-charity-ngo')
        ),
	)   );
    
	//Topbar section
	$wp_customize->add_section('vw_charity_ngo_topbar',array(
		'title'	=> __('Topbar Section','vw-charity-ngo'),
		'description'	=> __('Add TopBar Content here','vw-charity-ngo'),
		'priority'	=> null,
		'panel' => 'vw_charity_ngo_panel_id',
	));
	
	$wp_customize->add_setting('vw_charity_ngo_address',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_address',array(
		'label'	=> __('Add Location','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_address',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_contact',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_contact',array(
		'label'	=> __('Add Contact Details','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_contact',
		'type'		=> 'text'
	));	

	$wp_customize->add_setting('vw_charity_ngo_email',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_email',array(
		'label'	=> __('Add Email Address','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_email',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_text',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_text',array(
		'label'	=> __('Button Text','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_text',
		'type'		=> 'text'
	));

	$wp_customize->add_setting('vw_charity_ngo_link',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_link',array(
		'label'	=> __('Button Link','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_topbar',
		'setting'	=> 'vw_charity_ngo_link',
		'type'		=> 'text'
	));

	//Slider
	$wp_customize->add_section( 'vw_charity_ngo_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	for ( $count = 1; $count <= 4; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_slider_page' . $count, array(
			'label'    => __( 'Select Slide Image Page', 'vw-charity-ngo' ),
			'section'  => 'vw_charity_ngo_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	//Scholarship
	$wp_customize->add_section( 'vw_charity_ngo_scholarship' , array(
    	'title'      => __( 'Scholarship Section', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	for ( $count = 1; $count <= 3; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_scholarship_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_scholarship_page' . $count, array(
			'label'    => __( 'Select Scholarship Page', 'vw-charity-ngo' ),
			'section'  => 'vw_charity_ngo_scholarship',
			'type'     => 'dropdown-pages'
		) );
	}

	//What We Do
	$wp_customize->add_section( 'vw_charity_ngo_what_do' , array(
    	'title'      => __( 'What we do Section', 'vw-charity-ngo' ),
		'priority'   => null,
		'panel' => 'vw_charity_ngo_panel_id'
	) );

	$wp_customize->add_setting('vw_charity_ngo_what_title',array(
		'default'	=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_what_title',array(
		'label'	=> __('Section Title','vw-charity-ngo'),
		'section'	=> 'vw_charity_ngo_what_do',
		'setting'	=> 'vw_charity_ngo_what_title',
		'type'		=> 'text'
	));

	for ( $count = 1; $count <= 3; $count++ ) {

		// Add color scheme setting and control.
		$wp_customize->add_setting( 'vw_charity_ngo_what_do_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'absint'
		) );
		$wp_customize->add_control( 'vw_charity_ngo_what_do_page' . $count, array(
			'label'    => __( 'Select What we do Page', 'vw-charity-ngo' ),
			'section'  => 'vw_charity_ngo_what_do',
			'type'     => 'dropdown-pages'
		) );
	}

	//Footer Text
	$wp_customize->add_section('vw_charity_ngo_footer',array(
		'title'	=> __('Footer','vw-charity-ngo'),
		'description'=> __('This section will appear in the footer','vw-charity-ngo'),
		'panel' => 'vw_charity_ngo_panel_id',
	));	
	
	$wp_customize->add_setting('vw_charity_ngo_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('vw_charity_ngo_footer_text',array(
		'label'	=> __('Copyright Text','vw-charity-ngo'),
		'section'=> 'vw_charity_ngo_footer',
		'setting'=> 'vw_charity_ngo_footer_text',
		'type'=> 'text'
	));	
}

add_action( 'customize_register', 'vw_charity_ngo_customize_register' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class vw_charity_ngo_customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	 */
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'VW_Charity_NGO_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section(
			new VW_Charity_NGO_Customize_Section_Pro(
				$manager,
				'example_1',
				array(
					'priority'   => 9,
					'title'    => esc_html__( 'VW Charity NGO Pro', 'vw-charity-ngo' ),
					'pro_text' => esc_html__( 'Upgrade Pro', 'vw-charity-ngo' ),
					'pro_url'  => esc_url('https://www.vwthemes.com/themes/premium-charity-wordpress-theme/'),
				)
			)
		);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'vw-charity-ngo-customize-controls', trailingslashit( get_template_directory_uri() ) . '/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'vw-charity-ngo-customize-controls', trailingslashit( get_template_directory_uri() ) . '/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
vw_charity_ngo_customize::get_instance();